==> identity-apps-1.0.117-source-release.zip: identity-apps-1.0.117/modules/i18n/src/translations/pt-BR/portals/common.ts <==
/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { CommonNS } from "../../../models";

export const common: CommonNS = {
    access: "Acesso",
    active: "Activo",
    add: "AAdicionar",
    all: "Tudo",
    applicationName: "Nome da Aplicação",
    applications: "Formulários",
    approvalStatus: "Status de aprovação",
    approve: "Approve",
    assignees: "Cessionárias",
    browser: "Navegador",
    cancel: "Cancelar",
    challengeQuestionNumber: "Questão Desafio {{number}}",
    change: "Mudança",
    claim: "Afirmação",
    completed: "Concluído",
    configure: "Configurar",
    contains: "Contém",
    continue: "Continuar",
    createdOn: "Criado em",
    dangerZone: "Zona de perigo",
    delete: "Excluir",
    description: "Descrição",
    deviceModel: "Modelo do dispositivo",
    edit: "Editar",
    endsWith: "Termina com",
    equals: "É igual a",
    filter: "Filtro",
    goBackHome: "Volto para casa",
    help: "Socorro",
    hidePassword: "Esconder a senha",
    initiator: "Iniciador",
    ipAddress: "endereço de IP",
    lastAccessed: "Último acesso",
    lastSeen: "Visto pela última vez",
    loginTime: "Hora de início de sessão",
    logout: "Sair",
    more: "Mais",
    name: "Nome",
    operatingSystem: "Sistema operacional",
    operations: "Operações",
    overview: "visão global",
    personalInfo: "Informação pessoal",
    priority: "Prioridade",
    privacy: "Privacidade",
    properties: "Propriedades",
    ready: "Pronta",
    reject: "Aprovar",
    release: "Liberação",
    remove: "Retirar",
    removeAll: "Remover tudo",
    reserved: "Reservado",
    resetFilters: "Redefinir filtros",
    retry: "Repetir",
    revoke: "Revogar",
    revokeAll: "Revogar tudo",
    save: "Salve",
    search: "Procurar",
    security: "Segurança",
    showAll: "Mostre tudo",
    showLess: "Mostre menos",
    showMore: "Mostre mais",
    showPassword: "Mostrar senha",
    startsWith: "Começa com",
    submit: "Enviar",
    switch: "Interruptor",
    terminate: "Terminar",
    terminateAll: "Terminar tudo",
    terminateSession: "Encerrar sessão",
    type: "Tipo",
    update: "Atualizar",
    user: "Do utilizador"
};

==> identity-apps-1.0.217-source-release.zip: identity-apps-1.0.217/modules/i18n/src/translations/pt-BR/portals/common.ts <==
/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { CommonNS } from "../../../models";

export const common: CommonNS = {
    access: "Acesso",
    active: "Activo",
    add: "AAdicionar",
    all: "Tudo",
    applicationName: "Nome da Aplicação",
    applications: "Formulários",
    approvalStatus: "Status de aprovação",
    approve: "Approve",
    assignees: "Cessionárias",
    browser: "Navegador",
    cancel: "Cancelar",
    challengeQuestionNumber: "Questão Desafio {{number}}",
    change: "Mudança",
    claim: "Afirmação",
    close: "Fechar",
    completed: "Concluído",
    configure: "Configurar",
    contains: "Contém",
    continue: "Continuar",
    createdOn: "Criado em",
    dangerZone: "Zona de perigo",
    delete: "Excluir",
    description: "Descrição",
    deviceModel: "Modelo do dispositivo",
    docs: "Documentos",
    documentation: "Documentação",
    done: "Feito",
    download: "Baixar",
    edit: "Editar",
    endsWith: "Termina com",
    equals: "É igual a",
    filter: "Filtro",
    goBackHome: "Volto para casa",
    help: "Socorro",
    hidePassword: "Esconder a senha",
    identityProviders: "Fornecedor de identidade",
    initiator: "Iniciador",
    ipAddress: "endereço de IP",
    lastAccessed: "Último acesso",
    lastSeen: "Visto pela última vez",
    loginTime: "Hora de início de sessão",
    logout: "Sair",
    more: "Mais",
    myAccount: "Minha conta",
    name: "Nome",
    operatingSystem: "Sistema operacional",
    operations: "Operações",
    overview: "visão global",
    personalInfo: "Informação pessoal",
    pin: "Bastão",
    pinned: "Bastão",
    priority: "Prioridade",
    privacy: "Privacidade",
    properties: "Propriedades",
    ready: "Pronta",
    reject: "Aprovar",
    release: "Liberação",
    remove: "Retirar",
    removeAll: "Remover tudo",
    reserved: "Reservado",
    resetFilters: "Redefinir filtros",
    retry: "Repetir",
    revoke: "Revogar",
    revokeAll: "Revogar tudo",
    samples: "Amostras",
    save: "Salve",
    services: "Serviços",
    sdks: "SDKs",
    search: "Procurar",
    security: "Segurança",
    showAll: "Mostre tudo",
    showLess: "Mostre menos",
    showMore: "Mostre mais",
    showPassword: "Mostrar senha",
    startsWith: "Começa com",
    submit: "Enviar",
    switch: "Interruptor",
    technologies: "Tecnologias",
    terminate: "Terminar",
    terminateAll: "Terminar tudo",
    terminateSession: "Encerrar sessão",
    type: "Tipo",
    unpin: "Solto",
    unpinned: "Solto",
    update: "Atualizar",
    user: "Do utilizador",
    verify: "Verificar"
};
